//
// FileContainer.java
// This file is part of PosterDivider.
//
package jp.sourceforge.posterdivider;

import java.awt.image.BufferedImage;
import java.io.ByteArrayInputStream;
import java.io.File;
import javax.imageio.ImageIO;

import com.itextpdf.text.Image;
import com.itextpdf.text.pdf.PdfReader;
//import com.lowagie.text.*;
//import com.lowagie.text.pdf.*;

/**
 * Contains file contents.
 * 
 * @author ankys
 * 
 */
public class FileContainer {
    private byte[] data;
    private int fileType;
    private PdfReader pdf;
    private Image image;
    private BufferedImage awtImage;
    
    private void init(byte[] data) throws Exception {
	this.data = data;
	this.fileType = Lib.FT_NONE;
	if (this.fileType == Lib.FT_NONE) {
	    try {
		PdfReader pdf = new PdfReader(data);
		this.fileType = Lib.FT_PDF;
		this.pdf = pdf;
	    } catch (Throwable ex) {
		//java.lang.NoClassDefFoundError もある
		this.fileType = Lib.FT_NONE;
	    }
	}
	if (this.fileType == Lib.FT_NONE) {
	    try {
		Image image = Image.getInstance(data);
		this.fileType = Lib.getImageFileType(image);
		this.image = image;
	    } catch (Exception ex) {
		this.fileType = Lib.FT_NONE;
	    }
	}
	if (this.fileType == Lib.FT_NONE) {
	    throw new Exception();
	}
	try {
	    ByteArrayInputStream is = new ByteArrayInputStream(data);
	    this.awtImage = ImageIO.read(is);
	    is.close();
	} catch (Exception ex) {
	    this.awtImage = null;
	}
    }
    
    public FileContainer(File file) throws Exception {
	byte[] data = Lib.FileReadAllBytes(file);
	init(data);
    }
    
    public FileContainer(byte[] data) throws Exception {
	init(data);
    }

	public int getFileType() {
		return this.fileType;
	}

	public PdfReader getPdf() {
		return this.pdf;
	}

	public Image getImage() {
		return this.image;
	}

	public int getPageCount() {
		switch (this.fileType) {
		case Lib.FT_PDF:
			return this.pdf.getNumberOfPages();
		case Lib.FT_BMP:
		case Lib.FT_GIF:
		case Lib.FT_JBIG2:
		case Lib.FT_JPEG:
		case Lib.FT_JPEG2000:
		case Lib.FT_PNG:
		case Lib.FT_TIFF:
		case Lib.FT_WMF:
		case Lib.FT_OTHERIMAGE:
			return 1;
		default:
			return -1;
		}
	}

	public BufferedImage getAwtImage() {
		return this.awtImage;
	}
}
